@@ -25,10 +25,10 @@
 #' for using a function as threshold.  A threshold is needed for calculation e.g. 
 #' of head count ratios and poverty gaps. The argument defaults to \code{NULL}. 
 #' In this case the threshold is set to 60\% of the median of the variable that 
-#' is selected as y similary to the At-risk-of-poverty rate used in the EU (see 
-#' also \cite{Social Protection Committee 2001}). However, any desired threshold 
-#' can be chosen.
-#' @param var if \code{TRUE}, estimates for the variance are calcualted using a 
+#' is selected as \code{y} similary to the at-risk-of-poverty rate used in the 
+#' EU (see also \cite{Social Protection Committee 2001}). However, any desired 
+#' threshold can be chosen.
+#' @param var if \code{TRUE}, estimates for the variance are calculated using a 
 #' naive or calibrated bootstrap. Defaults to \code{FALSE}.
 #' @param boot_type a character string containing the name of the bootstrap 
 #' specification. Either a \code{"naive"} or a \code{"calibrate"} bootstrap can 
@@ -45,27 +45,27 @@
 #' equal the number of columns in X_calib. Defaults to \code{NULL}. In this case, 
 #' the sampling weights are used to calculate the totals.
 #' @param custom_indicator a list of functions containing the indicators to be
-#' calculated additionaly. Such functions must and must only depend on the
+#' calculated additionally. Such functions must and must only depend on the
 #' target variable \code{y}, the \code{weights} and the 
 #' \code{threshold} (numeric value) (see Example 3) even though some arguments 
 #' might not be used in the additional function. Defaults to \code{NULL}.
-#' @param na.rm if TRUE, observations with \code{NA} values are deleted from the 
-#' sample data. Defaults to \code{FALSE}. 
+#' @param na.rm if \code{TRUE}, observations with \code{NA} values are deleted 
+#' from the sample data. Defaults to \code{FALSE}. 
 #' @return An object of class "emdi" that provides direct estimators for regional
 #' disaggregated indicators and optionally corresponding variance estimates. Generic
-#' functions such as \code{\link{estimators}}, \code{\link{print}}, 
+#' functions such as \code{\link{estimators}}, \code{\link{print}} 
 #' and \code{\link{summary}} have methods that can be used
 #' to obtain further information. See \code{\link{emdiObject}} for descriptions
 #' of components of objects of class "emdi".
 #' @details The set of predefined indicators includes the mean, median, four 
 #' further quantiles (10\%, 25\%, 75\% and 90\%), head count ratio, poverty gap, 
-#' Gini coefficient and the quintile share ratio.
+#' Gini coefficient and the quintile share ratio. 
 #' @references
 #' Alfons, A. and Templ, M. (2013). Estimation of Social Exclusion Indicators
-#' from complex Surveys: The R package laeken. Journal of Statistical Software, 
-#' 54(15), 1-25.  \cr \cr
-#' Social Protection Committee (2001). Report on indicators in the field of
-#' poverty and social exclusions, Technical Report, European Union.
+#' from Complex Surveys: The \R Package \pkg{laeken}. Journal of 
+#' Statistical Software, 54(15), 1-25.  \cr \cr
+#' Social Protection Committee (2001). Report on Indicators in the Field of
+#' Poverty and Social Exclusions, Technical Report, European Union.
 #' @seealso \code{\link{emdiObject}}, \code{\link[nlme]{lme}},
 #' \code{\link{estimators.emdi}}, \code{\link{print.emdi}}, 
 #' \code{\link{summary.emdi}}
@@ -89,7 +89,7 @@
 #' emdi_direct <- direct(y = "eqIncome", smp_data = eusilcA_smp, 
 #' smp_domains = "district", weights = "weight", threshold = 10859.24, 
 #' var = TRUE, boot_type = "naive", B = 50, seed = 123, X_calib = NULL, 
-#' totals = NULL, custom_indicator = list( my_max = function(y, weights, 
+#' totals = NULL, custom_indicator = list(my_max = function(y, weights, 
 #' threshold){max(y)}, my_min = function(y, weights, threshold){min(y)}), 
 #' na.rm = TRUE)
 #' }
@@ -150,9 +150,8 @@ direct <- function(y,
                   SIMPLIFY = F
   )
 
-
-  if(var == TRUE){
-    warnlist <- character()
+  warnlist <- character()
+  if (var == TRUE) {
     envir <- environment()
     res <- mapply(FUN = direct_variance,
                   direct_estimator =  framework$indicator_list,
@@ -174,10 +173,13 @@ direct <- function(y,
                            ),
                   SIMPLIFY = F
     )
-    if(length(warnlist) >0){
+    if (length(warnlist) > 0) {
       warning(paste0("For the following domains at least one bootstrap failed ",
                      ", this may be due to a very small sample size. For these domains ",
-                     "no MSE estimate is displayed. ", paste0(unique(warnlist), collapse = ", ")))
+                     "the variance estimation is based on a reduced number of ",
+                     "bootstrap iteration. To see the number of successful" ,
+                     " bootstrap iterations for each domain and indicator, have a look at",
+                     " the value successful_bootstraps in the returned object."))
     }
   } else {
     res <- result_point
@@ -188,7 +190,7 @@ direct <- function(y,
   ind <- cbind(res[[1]]$valueByDomain$Domain, 
               as.data.frame(lapply(res, function(erg){erg$valueByDomain[,2]}))
   )
-  if(!var) {
+  if (!var) {
     MSE <- NULL 
     colnames(ind) <- c("Domain", framework$indicator_names)
     } else {
@@ -198,14 +200,37 @@ direct <- function(y,
       colnames(MSE) <- colnames(ind) <- c("Domain", framework$indicator_names)
     }
   
-  direct_out <- list(
+  if (length(warnlist) > 0) {
+    failed_BS <- do.call(rbind, lapply(strsplit(warnlist, split = ":_:"), t))
+    colnames(failed_BS) <- c("Domain", "Indicator")
+    failed_BS <- as.data.frame(failed_BS)
+    failed_BS$Domain <- factor(failed_BS$Domain, 
+                               levels = levels(framework$smp_domains_vec))
+    failed_BS$Indicator <- factor(failed_BS$Indicator, 
+                                  levels = framework$indicator_names)
+    sucInd <- B - table(failed_BS$Domain, failed_BS$Indicator)
+  }
+  else {
+    failed_BS <- matrix(data = 0, 
+                        nrow = length(levels(framework$smp_domains_vec)),
+                        ncol = length(framework$indicator_names),
+                        dimnames = list(levels(framework$smp_domains_vec), 
+                                        framework$indicator_names)
+                        )
+    sucInd <- B - failed_BS
+    
+  }
+  
+   direct_out <- list(
     ind = ind, 
     MSE = MSE,
-    framework=framework[c("N_dom_smp",
+    framework = framework[c("N_dom_smp",
                          "N_smp",
                          "smp_domains",
                          "smp_domains_vec")],
-    call = call)
+    call = call,
+    successful_bootstraps = sucInd
+    )
   
   class(direct_out) <- c("emdi", "direct")
   return(direct_out)
