@@ -12,22 +12,24 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
   #smp_domains_orig <- smp_domains
   
   # Reduction of number of variables
-  mod_vars <- gsub(" ", "",unlist(strsplit(paste(fixed[3]), "[+]")), 
-                   fixed = TRUE)
-  
-  fw_check1(pop_data = pop_data, mod_vars = mod_vars, pop_domains = pop_domains, 
-           smp_data = smp_data, fixed = fixed, smp_domains = smp_domains)
- 
-  pop_vars <- c(mod_vars, pop_domains)
-  pop_data <- pop_data[, pop_vars]
+  mod_vars <- all.vars(fixed)
+  mod_vars <- mod_vars[mod_vars != as.character(fixed[2])]
   smp_vars <- c(as.character(fixed[2]), mod_vars, smp_domains)
+  pop_vars <- c(mod_vars, pop_domains)
   smp_data <- smp_data[, smp_vars]
+  fw_check1(pop_data = pop_data, mod_vars = mod_vars, pop_domains = pop_domains, 
+           smp_data = smp_data, fixed = fixed, smp_domains = smp_domains, 
+           threshold = threshold)
+ 
+
+  pop_data <- pop_data[, pop_vars]
+
   
   # Deletion of NA
-  if (na.rm == T) {
+  if (na.rm == TRUE) {
     pop_data <- na.omit(pop_data)
     smp_data <- na.omit(smp_data)
-  } else if(any(is.na(pop_data)) || any(is.na(smp_data))){
+  } else if (any(is.na(pop_data)) || any(is.na(smp_data))){
     stop('EBP does not work with missing values. Set na.rm = TRUE in function 
           ebp.')
   }
@@ -35,11 +37,13 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
   
   # Order of domains
   pop_data <- pop_data[order(pop_data[[pop_domains]]),]
-  pop_data[[pop_domains]] <- factor(pop_data[[pop_domains]], levels = unique(pop_data[[pop_domains]]))
+  pop_data[[pop_domains]] <- factor(pop_data[[pop_domains]], 
+                                    levels = unique(pop_data[[pop_domains]]))
   pop_domains_vec <- pop_data[[pop_domains]]
 
   smp_data <- smp_data[order(smp_data[[smp_domains]]),]
-  smp_data[[smp_domains]] <- factor(smp_data[[smp_domains]], levels = unique(pop_data[[pop_domains]]))
+  smp_data[[smp_domains]] <- factor(smp_data[[smp_domains]], 
+                                    levels = unique(pop_data[[pop_domains]]))
   smp_domains_vec <- smp_data[[smp_domains]]
   smp_domains_vec <- droplevels(smp_domains_vec)
   
@@ -122,9 +126,8 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
     threshold <- 0.6 * median(smp_data[[paste(fixed[2])]])
     cat("The threshold for the HCR and the PG is automatically set to 60% of 
         the median of the dependent variable and equals",threshold, "\n")
-  } else {
-    threshold <- threshold
   }
+  
 
   return(list(pop_data         = pop_data,
               pop_domains_vec  = pop_domains_vec,
